@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive, WindowsVolume
+from netbox_storage.models import Filesystem, Drive, LinuxVolume, Partition, PhysicalVolume
 
 
 #
@@ -19,16 +19,17 @@ class NestedFilesystemSerializer(WritableNestedSerializer):
 
 
 #
-# WindowsVolume
+# LinuxVolume
 #
-class NestedWindowsVolumeSerializer(WritableNestedSerializer):
+
+class NestedLinuxVolumeSerializer(WritableNestedSerializer):
     url = serializers.HyperlinkedIdentityField(
-        view_name="plugins-api:netbox_storage-api:windowsvolume-detail"
+        view_name="plugins-api:netbox_storage-api:linuxvolume-detail"
     )
 
     class Meta:
-        model = WindowsVolume
-        fields = ["id", "url", "display", "drive_name"]
+        model = LinuxVolume
+        fields = ["id", "url", "display", "vg_name"]
 
 
 #
@@ -42,3 +43,29 @@ class NestedDriveSerializer(WritableNestedSerializer):
     class Meta:
         model = Drive
         fields = ["id", "url", "display", "size", "identifier"]
+
+
+#
+# Partition
+#
+class NestedPartitionSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:partition-detail"
+    )
+
+    class Meta:
+        model = Partition
+        fields = ["id", "url", "display", "size", "device"]
+
+
+#
+# PhysicalVolume
+#
+class NestedPhysicalVolumeSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:physicalvolume-detail"
+    )
+
+    class Meta:
+        model = PhysicalVolume
+        fields = ["id", "url", "display", "partition"]
