@@ -2,13 +2,12 @@ from rest_framework import serializers
 
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedWindowsVolumeSerializer
-from netbox_storage.models import Drive, Filesystem, LinuxVolume, WindowsVolume
+    NestedPartitionSerializer
+from netbox_storage.models import Drive, Filesystem, LinuxVolume, Partition, PhysicalVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
 class FilesystemSerializer(serializers.ModelSerializer):
-
     class Meta:
         model = Filesystem
         fields = (
@@ -25,7 +24,6 @@ class DriveSerializer(NetBoxModelSerializer):
     cluster = NestedClusterSerializer(required=False, allow_null=True)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
     url = serializers.HyperlinkedIdentityField(view_name="plugins-api:netbox_storage-api:drive-detail")
-    windowsvolumes = NestedWindowsVolumeSerializer(many=True, read_only=True, required=False, default=None,)
 
     class Meta:
         model = Drive
@@ -38,7 +36,6 @@ class DriveSerializer(NetBoxModelSerializer):
             "virtual_machine",
             "identifier",
             "description",
-            "windowsvolumes",
             "created",
             "last_updated",
             "custom_fields",
@@ -63,43 +60,33 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
         )
 
 
-class WindowsVolumeSerializer(NetBoxModelSerializer):
-    url = serializers.HyperlinkedIdentityField(view_name="plugins-api:netbox_storage-api:windowsvolume-detail")
-    fs = NestedFilesystemSerializer(required=False, allow_null=True)
-    drives = NestedDriveSerializer(required=False, many=True, read_only=False)
-    virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
+class PartitionSerializer(serializers.ModelSerializer):
+    drive = NestedDriveSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = WindowsVolume
+        model = Partition
         fields = (
             "id",
-            "url",
-            "drive_name",
-            "fs",
-            "drives",
-            "virtual_machine",
+            "drive",
+            "device",
+            "size",
             "description",
             "created",
             "last_updated",
             "custom_fields",
         )
 
-    def create(self, validated_data):
-        drives = validated_data.pop("drives", None)
 
-        windowsvolume = super().create(validated_data)
+class PhysicalVolumeSerializer(serializers.ModelSerializer):
+    partition = NestedPartitionSerializer(required=False, allow_null=True)
 
-        if drives is not None:
-            windowsvolume.drives.set(drives)
-
-        return windowsvolume
-
-    def update(self, instance, validated_data):
-        drives = validated_data.pop("drives", None)
-
-        windowsvolume = super().update(instance, validated_data)
-
-        if drives is not None:
-            windowsvolume.drives.set(drives)
-
-        return windowsvolume
\ No newline at end of file
+    class Meta:
+        model = PhysicalVolume
+        fields = (
+            "id",
+            "partition",
+            "description",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
