@@ -20,13 +20,13 @@ class Migration(migrations.Migration):
                     ),
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("size", models.PositiveIntegerField()),
-                ('cluster',
-                 models.ForeignKey(on_delete=models.deletion.PROTECT, related_name='drive',
-                                   to='virtualization.cluster')),
-                ('virtual_machine',
+                ("cluster",
+                 models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="cluster_drive",
+                                   to="virtualization.cluster")),
+                ("virtual_machine",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name='drive', to='virtualization.virtualmachine')),
+                                   related_name="virtual_machine_drive", to="virtualization.virtualmachine")),
+                ("size", models.PositiveIntegerField()),
                 ("identifier", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
             ],
@@ -34,6 +34,54 @@ class Migration(migrations.Migration):
                 "ordering": ("size", "id"),
             },
         ),
+        migrations.CreateModel(
+            name="Partition",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("drive",
+                 models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="drive_partition",
+                                   to="netbox_storage.drive")),
+                ("device", models.CharField(max_length=255)),
+                ("size", models.PositiveIntegerField()),
+                ("description", models.CharField(max_length=255)),
+            ],
+            options={
+                "ordering": ("size", "id"),
+            },
+        ),
+        migrations.CreateModel(
+            name="PhysicalVolume",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("partition",
+                 models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="partition_physicalvolume",
+                                   to="netbox_storage.partition")),
+                ("description", models.CharField(max_length=255)),
+            ],
+            options={
+                "ordering": ("size", "id"),
+            },
+        ),
         migrations.CreateModel(
             name="Filesystem",
             fields=[
@@ -69,10 +117,13 @@ class Migration(migrations.Migration):
                     ),
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("physical_volume", models.ForeignKey(on_delete=models.deletion.CASCADE,
+                                                      related_name="linux_physicalvolume",
+                                                      to="netbox_storage.physicalvolume")),
                 ("vg_name", models.CharField(max_length=255)),
                 ("lv_name", models.CharField(max_length=255)),
                 ("path", models.CharField(max_length=255)),
-                ('fs',
+                ("fs",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_linux',
                                    to='netbox_storage.filesystem')),
                 ("description", models.CharField(max_length=255)),
@@ -81,37 +132,4 @@ class Migration(migrations.Migration):
                 "ordering": ("lv_name", "id"),
             },
         ),
-        migrations.CreateModel(
-            name="WindowsVolume",
-            fields=[
-                ("created", models.DateTimeField(auto_now_add=True, null=True)),
-                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
-                (
-                    "custom_field_data",
-                    models.JSONField(
-                        blank=True,
-                        default=dict,
-                        encoder=utilities.json.CustomFieldJSONEncoder
-                    ),
-                ),
-                ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("drive_name", models.CharField(max_length=255)),
-                ("fs",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_windows',
-                                   to='netbox_storage.filesystem')),
-                (
-                    "drives",
-                    models.ManyToManyField(
-                        blank=True, related_name="drives", to="netbox_storage.drive"
-                    ),
-                ),
-                ('virtual_machine',
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name='drive_volume', to='virtualization.virtualmachine')),
-                ("description", models.CharField(max_length=255)),
-            ],
-            options={
-                "ordering": ("drive_name", "id"),
-            },
-        ),
     ]
