@@ -5,18 +5,18 @@ from netbox.models import NetBoxModel
 
 
 class Drive(NetBoxModel):
-    size = models.PositiveIntegerField(
-        verbose_name="Size (GB)"
-    )
     cluster = models.ForeignKey(
         to='virtualization.Cluster',
         on_delete=models.PROTECT,
-        related_name='drive',
+        related_name='cluster_drive',
     )
     virtual_machine = models.ForeignKey(
         to='virtualization.VirtualMachine',
         on_delete=models.CASCADE,
-        related_name='drive',
+        related_name='virtual_machine_drive',
+    )
+    size = models.PositiveIntegerField(
+        verbose_name="Size (GB)"
     )
     identifier = models.CharField(
         max_length=255,
@@ -26,7 +26,7 @@ class Drive(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["size", "identifier", "cluster", "virtual_machine", "description"]
+    clone_fields = ["cluster", "virtual_machine", "size", "identifier", "description"]
 
     prerequisite_models = (
         'virtualization.Cluster',
@@ -45,7 +45,8 @@ class Drive(NetBoxModel):
     def save(self, *args, **kwargs):
         is_already_implemented = Drive.objects.filter(id=self.pk).count()
         if is_already_implemented == 0:
-            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").count()
+            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created")\
+                .count()
 
             self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
 
@@ -55,6 +56,68 @@ class Drive(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/drive/'
 
+    def partition_count(self):
+        return Partition.objects.filter(drive=self).count()
+
+
+class Partition(NetBoxModel):
+    drive = models.ForeignKey(
+        Drive,
+        on_delete=models.CASCADE,
+        related_name='drive_partition',
+    )
+    device = models.CharField(
+        max_length=255,
+    )
+    size = models.PositiveIntegerField(
+        verbose_name="Size (GB)"
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = ["drive", "device", "size", "description"]
+
+    class Meta:
+        ordering = ["size"]
+
+    def __str__(self):
+        return self.device
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:partition", kwargs={"pk": self.pk})
+
+    @property
+    def docs_url(self):
+        return f'https://confluence.ti8m.ch/docs/models/partition/'
+
+
+class PhysicalVolume(NetBoxModel):
+    partition = models.ForeignKey(
+        Partition,
+        on_delete=models.CASCADE,
+        related_name='partition_physicalvolume',
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = [
+            "partition",
+            "description",
+        ]
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"PV has XXX Partition"
+
+    class Meta:
+        ordering = ("partition", "description")
+
 
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
@@ -79,6 +142,12 @@ class Filesystem(NetBoxModel):
 
 
 class LinuxVolume(NetBoxModel):
+    physical_volume = models.ForeignKey(
+        PhysicalVolume,
+        on_delete=models.CASCADE,
+        related_name="linux_physicalvolume",
+        verbose_name="Physical Volume",
+    )
     vg_name = models.CharField(
         max_length=255,
     )
@@ -100,6 +169,7 @@ class LinuxVolume(NetBoxModel):
     )
 
     clone_fields = [
+            "physical_volume",
             "vg_name",
             "lv_name",
             "path",
@@ -107,10 +177,6 @@ class LinuxVolume(NetBoxModel):
             "description",
         ]
 
-    prerequisite_models = (
-        'dcim.platform'
-    )
-
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
 
@@ -119,50 +185,3 @@ class LinuxVolume(NetBoxModel):
 
     class Meta:
         ordering = ("vg_name", "lv_name", "path")
-
-
-class WindowsVolume(NetBoxModel):
-    drive_name = models.CharField(
-        max_length=255,
-    )
-    fs = models.ForeignKey(
-        Filesystem,
-        on_delete=models.CASCADE,
-        related_name="fs_windows",
-        verbose_name="Filesystem",
-    )
-    drives = models.ManyToManyField(
-        Drive,
-        related_name="drives",
-        verbose_name="Drives",
-    )
-    virtual_machine = models.ForeignKey(
-        to='virtualization.VirtualMachine',
-        on_delete=models.CASCADE,
-        related_name='drive_volume',
-    )
-    description = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-
-    clone_fields = [
-            "drive_name",
-            "fs",
-            "drives",
-            "virtual_machine",
-            "description",
-        ]
-
-    prerequisite_models = (
-        'dcim.platform'
-    )
-
-    def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:windowsvolume", kwargs={"pk": self.pk})
-
-    def __str__(self):
-        return f"Name: {self.drive_name} filesystem: {self.fs}"
-
-    class Meta:
-        ordering = ("drive_name", "fs")
