@@ -2,7 +2,7 @@ from django.urls import path
 
 from netbox.views.generic import ObjectChangeLogView
 
-from netbox_storage.models import Drive, Filesystem, LinuxVolume, LinuxVolumeDrive
+from netbox_storage.models import Drive, Filesystem, LinuxVolume, Partition, PhysicalVolume
 from netbox_storage.views import (
     # Drive View
     DriveListView,
@@ -28,14 +28,22 @@ from netbox_storage.views import (
     LinuxVolumeBulkImportView,
     LinuxVolumeBulkEditView,
     LinuxVolumeBulkDeleteView,
-    # LinuxVolume
-    LinuxVolumeDriveListView,
-    LinuxVolumeDriveView,
-    LinuxVolumeDriveDeleteView,
-    LinuxVolumeDriveEditView,
-    LinuxVolumeDriveBulkImportView,
-    LinuxVolumeDriveBulkEditView,
-    LinuxVolumeDriveBulkDeleteView,
+    # Partition
+    PartitionListView,
+    PartitionEditView,
+    PartitionBulkImportView,
+    PartitionBulkEditView,
+    PartitionBulkDeleteView,
+    PartitionView,
+    PartitionDeleteView,
+    # PhysicalVolume
+    PhysicalVolumeListView,
+    PhysicalVolumeEditView,
+    PhysicalVolumeBulkImportView,
+    PhysicalVolumeBulkEditView,
+    PhysicalVolumeBulkDeleteView,
+    PhysicalVolumeView,
+    PhysicalVolumeDeleteView,
 )
 
 app_name = "netbox_storage"
@@ -93,20 +101,37 @@ urlpatterns = [
         kwargs={"model": LinuxVolume},
     ),
     #
-    # LinuxVolume urls
+    # Partition urls
     #
-    path("linuxvolumedrive/", LinuxVolumeDriveListView.as_view(), name="linuxvolumedrive_list"),
-    path("linuxvolumedrive/add/", LinuxVolumeDriveEditView.as_view(), name="linuxvolumedrive_add"),
-    path("linuxvolumedrive/import/", LinuxVolumeDriveBulkImportView.as_view(), name="linuxvolumedrive_import"),
-    path("linuxvolumedrive/edit/", LinuxVolumeDriveBulkEditView.as_view(), name="linuxvolumedrive_bulk_edit"),
-    path("linuxvolumedrive/delete/", LinuxVolumeDriveBulkDeleteView.as_view(), name="linuxvolumedrive_bulk_delete"),
-    path("linuxvolumedrive/<int:pk>/", LinuxVolumeDriveView.as_view(), name="linuxvolumedrive"),
-    path("linuxvolumedrive/<int:pk>/edit/", LinuxVolumeDriveEditView.as_view(), name="linuxvolumedrive_edit"),
-    path("linuxvolumedrive/<int:pk>/delete/", LinuxVolumeDriveDeleteView.as_view(), name="linuxvolumedrive_delete"),
+    path("partition/", PartitionListView.as_view(), name="partition_list"),
+    path("partition/add/", PartitionEditView.as_view(), name="partition_add"),
+    path("partition/import/", PartitionBulkImportView.as_view(), name="partition_import"),
+    path("partition/edit/", PartitionBulkEditView.as_view(), name="partition_bulk_edit"),
+    path("partition/delete/", PartitionBulkDeleteView.as_view(), name="partition_bulk_delete"),
+    path("partition/<int:pk>/", PartitionView.as_view(), name="partition"),
+    path("partition/<int:pk>/edit/", PartitionEditView.as_view(), name="partition_edit"),
+    path("partition/<int:pk>/delete/", PartitionDeleteView.as_view(), name="partition_delete"),
     path(
-        "linuxvolumedrive/<int:pk>/changelog/",
+        "partition/<int:pk>/changelog/",
         ObjectChangeLogView.as_view(),
-        name="linuxvolumedrive_changelog",
-        kwargs={"model": LinuxVolumeDrive},
+        name="partition_changelog",
+        kwargs={"model": Partition},
+    ),
+    #
+    # PhysicalVolume urls
+    #
+    path("physicalvolume/", PhysicalVolumeListView.as_view(), name="physicalvolume_list"),
+    path("physicalvolume/add/", PhysicalVolumeEditView.as_view(), name="physicalvolume_add"),
+    path("physicalvolume/import/", PhysicalVolumeBulkImportView.as_view(), name="physicalvolume_import"),
+    path("physicalvolume/edit/", PhysicalVolumeBulkEditView.as_view(), name="physicalvolume_bulk_edit"),
+    path("physicalvolume/delete/", PhysicalVolumeBulkDeleteView.as_view(), name="physicalvolume_bulk_delete"),
+    path("physicalvolume/<int:pk>/", PhysicalVolumeView.as_view(), name="physicalvolume"),
+    path("physicalvolume/<int:pk>/edit/", PhysicalVolumeEditView.as_view(), name="physicalvolume_edit"),
+    path("physicalvolume/<int:pk>/delete/", PhysicalVolumeDeleteView.as_view(), name="physicalvolume_delete"),
+    path(
+        "physicalvolume/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="physicalvolume_changelog",
+        kwargs={"model": PhysicalVolume},
     ),
 ]
