@@ -1,14 +1,15 @@
 from netbox.views import generic
 
-from netbox_storage.filters import DriveFilter
+from netbox_storage.filters import DriveFilter, PartitionFilter
 from netbox_storage.forms import (
     DriveImportForm,
     DriveFilterForm,
     DriveForm,
     DriveBulkEditForm
 )
-from netbox_storage.models import Drive
-from netbox_storage.tables import DriveTable
+from netbox_storage.models import Drive, Partition
+from netbox_storage.tables import DriveTable, PartitionTable
+from utilities.views import ViewTab, register_model_view
 
 
 class DriveListView(generic.ObjectListView):
@@ -54,3 +55,24 @@ class DriveBulkEditView(generic.BulkEditView):
 class DriveBulkDeleteView(generic.BulkDeleteView):
     queryset = Drive.objects.all()
     table = DriveTable
+
+
+@register_model_view(Drive, "partitions")
+class DrivePartitionListView(generic.ObjectChildrenView):
+    queryset = Drive.objects.all()
+    child_model = Partition
+    table = PartitionTable
+    filterset = PartitionFilter
+    template_name = "netbox_storage/drive/partition.html"
+    hide_if_empty = True
+
+    tab = ViewTab(
+        label="Partitions",
+        badge=lambda obj: obj.partition_count(),
+        hide_if_empty=True,
+    )
+
+    def get_children(self, request, parent):
+        return Partition.objects.restrict(request.user, "view").filter(
+            drive=parent
+        )
\ No newline at end of file
